.show-on-focus{border-radius:5px;box-shadow:0 0 2.9px rgba(0,0,0,.028),0 0 8.1px rgba(0,0,0,.04),0 0 19.6px rgba(0,0,0,.052),0 0 65px rgba(0,0,0,.08);color:#000!important;display:inline-block;font-weight:500;left:10px;position:absolute!important;text-decoration:none;top:10px}.show-on-focus:not(:focus){clip:rect(0,0,0,0);border-width:0;height:1px!important;margin:-1px;overflow:hidden;padding:0!important;white-space:nowrap;width:1px!important}.show-on-focus:focus{background-color:#fff!important;padding:1rem;z-index:999}.show-on-focus:hover{text-decoration:underline}#smartweb-footer{position:relative}#smartweb-footer .show-on-focus{color:#000!important}form .form-text{margin-bottom:.3em;margin-top:-.4em}#cookies-form #form-widgets-all_basic_cookies,#cookies-form .form-text p,#cookies-form label span.required{display:none}#gdpr-consent-banner{background:orange;display:none;left:0;padding:5px;position:fixed;top:0;width:100%;z-index:999999}.faceted-select-widget.faceted-zero-count-hidden .faceted-select-item-disabled{display:none}