form.tabbed-form-with-toggle fieldset legend.dropdown-toggle{cursor:pointer}form.tabbed-form-with-toggle fieldset:not(:first-child) legend.dropdown-toggle:after{display:inline-block;margin-left:7px;transform-origin:center center;transition:all .3s ease-in;vertical-align:middle}form.tabbed-form-with-toggle fieldset:not(:first-child) legend.dropdown-toggle.expanded:after{transform:rotate(180deg)}